#include <avr/io.h>
#include <avr/interrupt.h>  /* for sei() */
#include <util/delay.h>     /* for _delay_ms() */
#include <avr/pgmspace.h>   /* required by usbdrv.h */
#include "usbdrv.h"

#define RQ_SET_LED    0
#define RQ_GET_SWITCH 1
#define RQ_GET_LIGHT 2

/* ------------------------------------------------------------------------- */
/* ----------------------------- USB interface ----------------------------- */
/* ------------------------------------------------------------------------- */

usbMsgLen_t usbFunctionSetup(uint8_t data[8])
{
    usbRequest_t *rq = (void *)data;
    static uint8_t switch_state;  /* must stay valid when usbFunctionSetup returns */
    static uint16_t light_val;

    if (rq->bRequest == RQ_SET_LED)
    {
        uint8_t led_val = rq->wValue.bytes[0];
        uint8_t led_no  = rq->wIndex.bytes[0];

        if (led_val){
            //PORTC |= (1<<led_no);
	    if(led_no == 0)
	    {
		PORTC  = 0b00111110 ;
		PORTB  = 0b00000001 ;
	    }
            else if(led_no == 6)
            {
                PORTC  = 0b00101111 ;
                PORTB  = 0b00000001 ;
            }
            else if(led_no == 12)
            {
                PORTC  = 0b00111011 ;
                PORTB  = 0b00000001 ;
            }
            else if(led_no == 18)
            {
                PORTC  = 0b00111101 ;
                PORTB  = 0b00000001 ;
            }
            else if(led_no == 24)
            {
                PORTC  = 0b00011111 ;
                PORTB  = 0b00000001 ;
            }
            else if(led_no == 30)
            {
                PORTC  = 0b00110111 ;
                PORTB  = 0b00000001 ;
            }
            else if(led_no == 1)
	    {
		PORTC  = 0b00111110 ;
		PORTB  = 0b00000100 ;
	    }
            else if(led_no == 7)
            {
                PORTC  = 0b00101111 ;
                PORTB  = 0b00000100 ;
            }
            else if(led_no == 13)
            {
                PORTC  = 0b00111011 ;
                PORTB  = 0b00000100 ;
            }
            else if(led_no == 19)
            {
                PORTC  = 0b00111101 ;
                PORTB  = 0b00000100 ;
            }
            else if(led_no == 25)
            {
                PORTC  = 0b00011111 ;
                PORTB  = 0b00000100 ;
            }
            else if(led_no == 31)
            {
                PORTC  = 0b00110111 ;
                PORTB  = 0b00000100 ;
            }
	    else if(led_no == 2)
	    {
		PORTC  = 0b00111110 ;
		PORTB  = 0b00100000 ;
	    }
            else if(led_no == 8)
            {
                PORTC  = 0b00101111 ;
                PORTB  = 0b00100000 ;
            }
            else if(led_no == 14)
            {
                PORTC  = 0b00111011 ;
                PORTB  = 0b00100000 ;
            }
            else if(led_no == 20)
            {
                PORTC  = 0b00111101 ;
                PORTB  = 0b00100000 ;
            }
            else if(led_no == 26)
            {
                PORTC  = 0b00011111 ;
                PORTB  = 0b00100000 ;
            }
            else if(led_no == 32)
            {
                PORTC  = 0b00110111 ;
                PORTB  = 0b00100000 ;
            }
	    else if(led_no == 3)
	    {
		PORTC  = 0b00111110 ;
		PORTB  = 0b00010000 ;
	    }
            else if(led_no == 9)
            {
                PORTC  = 0b00101111 ;
                PORTB  = 0b00010000 ;
            }
            else if(led_no == 15)
            {
                PORTC  = 0b00111011 ;
                PORTB  = 0b00010000 ;
            }
            else if(led_no == 21)
            {
                PORTC  = 0b00111101 ;
                PORTB  = 0b00010000 ;
            }
            else if(led_no == 27)
            {
                PORTC  = 0b00011111 ;
                PORTB  = 0b00010000 ;
            }
            else if(led_no == 33)
            {
                PORTC  = 0b00110111 ;
                PORTB  = 0b00010000 ;
            }
	    else if(led_no == 4)
	    {
		PORTC  = 0b00111110 ;
		PORTB  = 0b00001000 ;
	    }
            else if(led_no == 10)
            {
                PORTC  = 0b00101111 ;
                PORTB  = 0b00001000 ;
            }
            else if(led_no == 16)
            {
                PORTC  = 0b00111011 ;
                PORTB  = 0b00001000 ;
            }
            else if(led_no == 22)
            {
                PORTC  = 0b00111101 ;
                PORTB  = 0b00001000 ;
            }
            else if(led_no == 28)
            {
                PORTC  = 0b00011111 ;
                PORTB  = 0b00001000 ;
            }
            else if(led_no == 34)
            {
                PORTC  = 0b00110111 ;
                PORTB  = 0b00001000 ;
            }
	    else if(led_no == 5)
	    {
		PORTC  = 0b00111110 ;
		PORTB  = 0b00000010 ;
	    }
            else if(led_no == 11)
            {
                PORTC  = 0b00101111 ;
                PORTB  = 0b00000010 ;
            }
            else if(led_no == 17)
            {
                PORTC  = 0b00111011 ;
                PORTB  = 0b00000010 ;
            }
            else if(led_no == 23)
            {
                PORTC  = 0b00111101 ;
                PORTB  = 0b00000010 ;
            }
            else if(led_no == 29)
            {
                PORTC  = 0b00011111 ;
                PORTB  = 0b00000010 ;
            }
            else if(led_no == 35)
            {
                PORTC  = 0b00110111 ;
                PORTB  = 0b00000010 ;
            }

	}
        else
	{
		if(led_no == 0)
            {
		PORTC  = 0b00000000 ;
                PORTB  = 0b00000000 ;
            }
                                                        	
	}
           // PORTC &= ~(1<<led_no);

        return 0;
    }

    return 0;   /* default for not implemented requests: return no data back to host */
}

/* ------------------------------------------------------------------------- */

int main(void)
{
    DDRC  = (1<<PC0)|(1<<PC1)|(1<<PC2)|(1<<PC3)|(1<<PC4)|(1<<PC5); // PC0..PC2 = Output, PC3..PC5 = Input
    DDRB  = (1<<PB0)|(1<<PB1)|(1<<PB2)|(1<<PB3)|(1<<PB4)|(1<<PB5);
    //PORTC  = (1<<PC0)|(1<<PC1)|(1<<PC2)|(1<<PC3)|(1<<PC4)|(1<<PC5);
    //PORTB  = (1<<PB0)|(1<<PB1)|(1<<PB2)|(1<<PB3)|(1<<PB4)|(1<<PB5);	
    usbInit();

    /* enforce re-enumeration, do this while interrupts are disabled! */
    usbDeviceDisconnect();
    _delay_ms(300);
    usbDeviceConnect();

    /* enable global interrupts */
    sei();

    /* main event loop */
    for(;;)
    {
        usbPoll();
    }

    return 0;
}

/* ------------------------------------------------------------------------- */
